import { ISemverLike, ISemver, IRangedSemver, ISemverCompareOptions } from './types';
/**
 * Get semver from string or array.
 * @param version - Target to convert.
 * @returns Array with semver parts.
 */
export declare function semverify(version: ISemverLike): ISemver | null;
/**
 * Compare semvers.
 * @param a - Semver to compare.
 * @param b - Semver to compare with.
 * @param options - Compare options.
 * @returns Equals or not.
 */
export declare function compareSemvers(a: ISemver, b: ISemver, options: ISemverCompareOptions): boolean;
/**
 * Get required semver parts count.
 * @param version - Semver parts or ranges.
 * @param options - Semver compare options.
 * @returns Required semver parts count.
 */
export declare function getRequiredSemverPartsCount(version: ISemver | IRangedSemver, options: ISemverCompareOptions): number;
/**
 * Ranged semver to regexp patterns.
 * @param rangedVersion - Ranged semver.
 * @param options - Semver compare options.
 * @returns Array of regexp pattern strings.
 */
export declare function rangedSemverToRegExp(rangedVersion: IRangedSemver, options: ISemverCompareOptions): string[][];
//# sourceMappingURL=semver.d.ts.map